@@ -1,7 +1,6 @@
-import re, math
+import math
 
 import pynumparser
-from crawlite import crawler
 from crawlite import BaseCrawler
 from crawlite import urlpattern, urlrender
 
@@ -35,6 +34,12 @@ def parse_page_range_expression(exp):
 
 class NaverKinCrawler(BaseCrawler):
     COMMENT_PAGE_COUNT = 100
+    PROXIES_LIST = [
+        # None,
+        {'https':'103.37.141.68:80'},
+        # {'https':'140.227.61.156:23456'},
+        # {'https':'121.254.195.12:8080'},
+    ]
 
     urlorders = [
         urlrender(
@@ -91,7 +96,7 @@ class NaverKinCrawler(BaseCrawler):
 
 
     def kin_detail_parser(self, response, parsed, meta):
-        print('kin_detal_parser')
+        # print('kin_detal_parser')
         question = dict(
             title = parsed['question_title'],
             url=response.url
@@ -198,7 +203,8 @@ def event_listener(module, event, count):
 
 def test_naverkin(keywords, page_range):
     nkc = NaverKinCrawler(keywords, page_range,
-        settings=settings,crawl_listener=event_listener
+        settings=settings,
+        # crawl_listener=event_listener
     )
     nkc.crawl()
     return nkc
